# coding: utf-8

"""
Gluish - some glue code and utils for luigi.

GLUISH_DATA: where common task place their artefacts
"""
import requests
import logging

requests.adapters.DEFAULT_RETRIES = 3
__version__ = '0.1.74'

# environment variable name
GLUISH_DATA = 'GLUISH_DATA'

try:
    import gluish.benchmark
    import gluish.colors
    import gluish.common
    import gluish.configuration
    import gluish.database
    import gluish.esindex
    import gluish.format
    import gluish.intervals
    import gluish.oai
    import gluish.parameter
    import gluish.path
    import gluish.task
    import gluish.utils
except ImportError as err:
    logging.warn('one or more imports failed: %s' % err)



# coding: utf-8

"""
Various intervals.
"""

import datetime

def every_minute(dt=datetime.datetime.utcnow(), fmt=None):
    """ just pass on the given date
    - why not minutely? http://english.stackexchange.com/q/3091/222 """
    date = datetime.datetime(dt.year, dt.month, dt.day, dt.hour, dt.minute, 1, 0, dt.tzinfo)
    if fmt is None:
        return date
    else:
        return date.strftime(fmt)

def hourly(dt=datetime.datetime.utcnow(), fmt=None):
    """ get a new datetime object every hour """
    date = datetime.datetime(dt.year, dt.month, dt.day, dt.hour, 1, 1, 0, dt.tzinfo)
    if fmt is None:
        return date
    else:
        return date.strftime(fmt)

def daily(date=datetime.date.today()):
    """ just pass on the given date """
    return date

def weekly(date=datetime.date.today()):
    """ weeks start at Monday """
    return date - datetime.timedelta(days=date.weekday())

def biweekly(date=datetime.date.today()):
    """ every two weeks """
    return datetime.date(date.year, date.month, 1 if date.day < 15 else 15)

def monthly(date=datetime.date.today()):
    """ Take a date object and return the first day of the month. """
    return datetime.date(date.year, date.month, 1)

def quarterly(date=datetime.date.today()):
    """ 1/1, 4/1, 7/1, 10/1 """
    return datetime.date(date.year, ((date.month - 1)//3) * 3 + 1, 1)

def semiyearly(date=datetime.date.today()):
    """ twice a year """
    return datetime.date(date.year, 1 if date.day < 7 else 7, 1)

def yearly(date=datetime.date.today()):
    """ once a year """
    return datetime.date(date.year, 1, 1)



# coding: utf-8

"""
Some glue around luigi.

Provides a base class, that autogenerates its output filenames based on some
tag, classname and parameters.

Additionally, provide some smaller utilities, like a TSV format, a benchmark
decorator and some task templates.
"""
from setuptools import setup
import sys

install_requires = [
    'BeautifulSoup==3.2.1',
    'astroid>=1.0.1',
    'colorama==0.3.3',
    'elasticsearch==1.3.0',
    'logilab-common==0.61.0',
    'luigi>=1.0.20',
    'nose==1.3.3',
    'pyisbn==1.0.0',
    'python-dateutil==2.2',
    'pytz==2014.4',
    'requests==2.5.1',
    'six==1.9.0',
    'urllib3==1.10',
    'wsgiref==0.1.2',
]

if sys.version_info < (2, 7):
    install_requires.append('ordereddict==1.1')

setup(name='gluish',
      version='0.1.74',
      description='Utils around Luigi.',
      url='https://github.com/miku/gluish',
      author='Martin Czygan',
      author_email='martin.czygan@gmail.com',
      packages=[
        'gluish',
      ],
      package_dir={'gluish': 'gluish'},
      install_requires=install_requires,
      extras_require={'sqlitebck': ['sqlitebck==1.2.1'],
                      'MySQL': ['MySQL-python==1.2.5']}
)
